@@ -54,21 +54,17 @@ class Geo_common:
             for head in data[0][1:]:
                 tmp = line[data[0].index(head)]
                 if not tmp: continue                                   # 允许出现空值 , 并直接跳过
-                tmp = tmp.strip().split(";")                           # group , raw_file_r1 , raw_file_r2 可以输入多个值, 用 ; 分割
-                if len(tmp) == 1 :
-                    self.samples[line[0]][head] = tmp[0]
-                else:
+                if head in ["group","raw_file_r1","raw_file_r2"]:      # 这三个key允许多个值, 一致使用列表元素
+                    tmp = tmp.strip().split(";")                           # group , raw_file_r1 , raw_file_r2 可以输入多个值, 用 ; 分割
                     self.samples[line[0]][head] = []
                     for i in tmp:
                         if not i: continue                             # 防止出现空值
                         self.samples[line[0]][head].append(i)
+                else:
+                    self.samples[line[0]][head] = tmp
             # 判断R1和R2是否对应
             r1s = self.samples[line[0]]["raw_file_r1"]
             r2s = self.samples[line[0]]["raw_file_r2"]
-            if type(r1s) != list:
-                r1s = r1s.split()
-            if type(r2s) != list:
-                r2s = r2s.split()
             if len(r1s) != len(r2s):
                 exit("错误: %s 的R1和R2文件数量不相等" %(line[0]))
             l1 = 0                                                      # read测序长度, 只取R1的第一个数据
